'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

const WizardContext = React__default.createContext(null);
const useWizard = () => {
    const [activeStepIndex, setActiveStepIndex] = React.useState(0);
    const [maxVisitedStepIndex, setMaxVisitedStepIndex] = React.useState(0);
    const goToStep = (stepIndex, { resetMaxStepIndex = false } = {}) => {
        setActiveStepIndex(stepIndex);
        setMaxVisitedStepIndex(resetMaxStepIndex ? stepIndex : Math.max(stepIndex, maxVisitedStepIndex));
    };
    const nextStep = () => {
        goToStep(activeStepIndex + 1);
    };
    const previousStep = () => {
        goToStep(Math.max(activeStepIndex - 1, 0));
    };
    const moveToStep = (stepIndex) => {
        goToStep(stepIndex);
    };
    const resetToStep = (stepIndex) => {
        goToStep(stepIndex, { resetMaxStepIndex: true });
    };
    let stepCheckIndex = 0;
    const getStep = () => {
        const stepIndex = stepCheckIndex;
        const stepState = {
            index: stepIndex,
            isActive: activeStepIndex === stepCheckIndex,
            hasBeenActive: maxVisitedStepIndex >= stepCheckIndex,
            nextStep: () => goToStep(stepIndex + 1),
            previousStep: () => goToStep(Math.max(stepIndex - 1, 0)),
            resetToStep: () => goToStep(stepIndex, { resetMaxStepIndex: true }),
            moveToStep: () => goToStep(stepIndex)
        };
        stepCheckIndex++;
        return stepState;
    };
    return {
        activeStepIndex,
        maxVisitedStepIndex,
        goToStep,
        nextStep,
        previousStep,
        getStep,
        moveToStep,
        resetToStep
    };
};
const Wizard = (props) => {
    const internalState = useWizard();
    return (React__default.createElement(WizardContext.Provider, { value: Object.assign({}, internalState) }, typeof props.children === "function"
        ? props.children(internalState)
        : props.children));
};
const WizardStep = (props) => {
    const wizardContext = React.useContext(WizardContext);
    if (wizardContext === null) {
        throw new Error("Wizard Step must be used as a child within a Wizard Component");
    }
    return props.children(wizardContext.getStep());
};

exports.useWizard = useWizard;
exports.Wizard = Wizard;
exports.WizardStep = WizardStep;
exports.default = Wizard;
